% FlopVersusTicToc
% Compares tictoc benchmarking versus flop benchmarking.
clc
% Example 1. 
% Compare Matrix*Vector (2n^2) with (Triangular Matrix) \ Vector (1*n^2)
nRepeat = 1000;
clc
fprintf('  n   tTriSolve/tMatVec\n--------------------------\n')
for n=100:100:1000
    b = randn(n,1);
    M = randn(n,n);
    L = tril(M);
    tic
    for k=1:nRepeat
        x = M*b;
    end
    tMatVec = toc;
    tic
    for k=1:nRepeat
        x = L\b;
    end
    tTriSolve = toc;
    fprintf(' %5d   %5.2f\n',n,tTriSolve/tMatVec)
end
fprintf('\nResults confirm that (Triangular backslash b) is O(n^2).\n')
fprintf('The results also show that flop counting is flawed, for if\n')
fprintf('flops told the whole story, then the tictoc ratio would be 1/2.\n\n')

    
% Example 2. 
% Compare Matrix*Matrix (2n^3 flops) with A\b (2n^3/3 flops)

fprintf('\n\n\n  n  tSlash/tProd\n-----------------------------\n')
for n=100:100:1000
    A = randn(n,n);
    B = randn(n,n);
    b = randn(n,n);
    nRepeat = 10;
    tic
    for k=1:nRepeat
       x = A\b;
    end
    tSlash = toc;
    tic
    for k=1:nRepeat
       C = A*B;
    end
    tProd = toc;
    fprintf('%5d   %5.2f\n',n,tSlash/tProd)
end
fprintf('\nResults confirm that (A backslash b) is O(n^3).\n')
fprintf('The results also show that flop counting is flawed, for if\n')
fprintf('flops told the whole story, then the tictoc ratio would be (2/3)/2 = 1/3\n')

